@@ -1,7 +1,7 @@
 from mindsdb_sql.exceptions import ParsingException
 
 
-def parse_sql(sql, dialect='sqlite'):
+def get_lexer_parser(dialect):
     if dialect == 'sqlite':
         from mindsdb_sql.parser import SQLParser
         from mindsdb_sql.lexer import SQLLexer
@@ -10,8 +10,17 @@ def parse_sql(sql, dialect='sqlite'):
         from mindsdb_sql.dialects.mysql.lexer import MySQLLexer
         from mindsdb_sql.dialects.mysql.parser import MySQLParser
         lexer, parser = MySQLLexer(), MySQLParser()
+    elif dialect == 'mindsdb':
+        from mindsdb_sql.dialects.mindsdb.lexer import MindsDBLexer
+        from mindsdb_sql.dialects.mindsdb.parser import MindsDBParser
+        lexer, parser = MindsDBLexer(), MindsDBParser()
     else:
         raise ParsingException(f'Unknown dialect {dialect}. Available options are: sqlite, mysql.')
+    return lexer, parser
+
+
+def parse_sql(sql, dialect='sqlite'):
+    lexer, parser = get_lexer_parser(dialect)
     tokens = lexer.tokenize(sql)
     ast = parser.parse(tokens)
     return ast
