@@ -1,8 +1,8 @@
 from sly import Parser
 
 from mindsdb_sql.ast import (ASTNode, Constant, Identifier, Select, BinaryOperation, UnaryOperation, Join, NullConstant,
-                             TypeCast, Tuple, OrderBy, Operation, Function, Parameter)
-from mindsdb_sql.ast.create_view import CreateView
+                             TypeCast, Tuple, OrderBy, Operation, Function, Parameter, BetweenOperation)
+from mindsdb_sql.dialects.mindsdb.create_view import CreateView
 from mindsdb_sql.exceptions import ParsingException
 from mindsdb_sql.lexer import SQLLexer
 from mindsdb_sql.utils import ensure_select_keyword_order
@@ -19,27 +19,10 @@ class SQLParser(Parser):
     )
 
     # Top-level statements
-    @_('create_view',
-       'select')
+    @_('select')
     def query(self, p):
         return p[0]
 
-    # CREATE VIEW
-
-    @_('CREATE VIEW identifier create_view_from_table_or_nothing AS LPAREN select RPAREN')
-    def create_view(self, p):
-        return CreateView(name=p.identifier.value,
-                          from_table=p.create_view_from_table_or_nothing,
-                          query=p.select)
-
-    @_('FROM identifier')
-    def create_view_from_table_or_nothing(self, p):
-        return p.identifier
-
-    @_('empty')
-    def create_view_from_table_or_nothing(self, p):
-        pass
-
     # SELECT
 
     @_('select OFFSET constant')
@@ -290,6 +273,9 @@ class SQLParser(Parser):
     def identifier(self, p):
         return Identifier(value=p.STAR)
 
+    @_('expr BETWEEN expr AND expr')
+    def expr(self, p):
+        return BetweenOperation(args=(p.expr0, p.expr1, p.expr2))
 
     @_('expr IS NOT expr',
        'expr NOT IN expr')
@@ -371,7 +357,12 @@ class SQLParser(Parser):
 
     @_('ID')
     def identifier(self, p):
-        return Identifier(value=p.ID)
+        value = p.ID
+        wrap = None
+        if value[0] == '`':
+            value = value.replace('`', '')
+            wrap = '`'
+        return Identifier(value=value, wrap=wrap)
 
     @_('PARAMETER')
     def parameter(self, p):
